@@ -821,7 +821,9 @@ calcDesc.bivar     <- function(x, g, xname = NULL, gname = NULL, margin=FALSE, b
   } else if(!is.numeric(x) && !is.numeric(g)) {
 
     res$class  <- "factfact"
-    res$tab <- table(x[ok], g[ok])
+#    res$tab <- table(x[ok], g[ok], useNA=InDots(..., arg="useNA", default = "no"))
+# do not use x[ok] here, as we could not use NAs in the output
+    res$tab <- table(x, g, useNA=InDots(..., arg="useNA", default = "no"))
     res$rfrq <- InDots(..., arg="rfrq", default = "111")
     res$conf.level <- conf.level
     res$verbose <- verbose
@@ -1080,7 +1082,7 @@ print.Desc.logical  <- function(x, digits = NULL, ...) {
     rownames(out) <- rownames(x$afrq)
     colnames(out) <- c("freq", "perc",
                        gettextf(c("lci%s", "uci%s"),
-                                Format(x$conf.level, digits=2, leading="drop")))
+                                Format(x$conf.level, digits=2, ldigits=0)))
 
     txt <- capture.output(print(StrTrim(out), quote=FALSE, right=TRUE, print.gap=2))
     cat(paste(txt[1], DescToolsOptions("footnote")[1],
