@@ -407,7 +407,7 @@ IntegerVector bottom_i(NumericVector v, unsigned int n)
 
 // Source
 // https://stackoverflow.com/questions/55212746/rcpp-fast-statistical-mode-function-with-vector-input-of-any-type
-// Author: Ralf Stubner
+// Author: Ralf Stubner, Joseph Wood
 
 // [[Rcpp::plugins(cpp11)]]
 #include <unordered_map>
@@ -457,6 +457,52 @@ SEXP fastMode( SEXP x, bool narm = false ){
 
 
 
+template <int RTYPE>
+Vector<RTYPE> fastModeImplX(Vector<RTYPE> x, bool narm){
+  if (narm) x = x[!is_na(x)];
+  int myMax = 1;
+  std::vector<typename Rcpp::traits::storage_type<RTYPE>::type> modes;
+  std::unordered_map<typename
+    Rcpp::traits::storage_type<RTYPE>::type, int> modeMap;
+  modeMap.reserve(x.size());
+  
+  for (std::size_t i = 0, len = x.size(); i < len; ++i) {
+    auto it = modeMap.find(x[i]);
+    
+    if (it != modeMap.end()) {
+      ++(it->second);
+      if (it->second > myMax) {
+        myMax = it->second;
+        modes.clear();
+        modes.push_back(x[i]);
+      } else if (it->second == myMax) {
+        modes.push_back(x[i]);
+      }
+    } else {
+      modeMap.insert({x[i], 1});
+    }
+  }
+  
+  Rcpp::Vector<RTYPE> myMode(modes.size());
+  std::copy(modes.cbegin(), modes.cend(), myMode.begin());
+  // special case for factors == INTSXP with "class" and "levels" attribute
+  if (x.hasAttribute("levels")){
+    myMode.attr("class") = x.attr("class");
+    myMode.attr("levels") = x.attr("levels");
+  }
+  myMode.attr("freq") = myMax;
+  return myMode;
+}
 
 
+template <>
+Vector<CPLXSXP> fastModeImplX(Vector<CPLXSXP> x, bool narm) {
+  stop("Not supported SEXP type!");
+}
+
+
+// [[Rcpp::export(name="fastModeX", rng=false)]]
+SEXP fastModeX( SEXP x, bool narm = false ){
+  RCPP_RETURN_VECTOR(fastModeImplX, x, narm);
+}
 
